==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowAccessControlConfigurationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The access control configuration policy.
 * @property allowedCallerIpAddresses The allowed caller IP address ranges.
 * @property openAuthenticationPolicies The authentication policies for workflow.
 */
public data class FlowAccessControlConfigurationPolicyArgs(
    public val allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null,
    public val openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs =
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder()
            .allowedCallerIpAddresses(
                allowedCallerIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .openAuthenticationPolicies(
                openAuthenticationPolicies?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowAccessControlConfigurationPolicyArgs].
 */
@PulumiTagMarker
public class FlowAccessControlConfigurationPolicyArgsBuilder internal constructor() {
    private var allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null

    private var openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("irinynxqsngemgqi")
    public suspend fun allowedCallerIpAddresses(`value`: Output<List<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = value
    }

    @JvmName("kdlwvahkfemvupji")
    public suspend fun allowedCallerIpAddresses(vararg values: Output<IpAddressRangeArgs>) {
        this.allowedCallerIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("aoedimwfkfvkicyc")
    public suspend fun allowedCallerIpAddresses(values: List<Output<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = Output.all(values)
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("cynibhxtsacvmljl")
    public suspend
    fun openAuthenticationPolicies(`value`: Output<OpenAuthenticationAccessPoliciesArgs>) {
        this.openAuthenticationPolicies = value
    }

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("uwdancsgkyskjevq")
    public suspend fun allowedCallerIpAddresses(`value`: List<IpAddressRangeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("utikfagggudqakfh")
    public suspend
    fun allowedCallerIpAddresses(argument: List<suspend IpAddressRangeArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("yegyqrjevdlxtxie")
    public suspend fun allowedCallerIpAddresses(
        vararg
        argument: suspend IpAddressRangeArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("tlnhjjmmednurhqp")
    public suspend
    fun allowedCallerIpAddresses(argument: suspend IpAddressRangeArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressRangeArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("ldkiylavisujrayb")
    public suspend fun allowedCallerIpAddresses(vararg values: IpAddressRangeArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("sdelnfhfodeumafy")
    public suspend fun openAuthenticationPolicies(`value`: OpenAuthenticationAccessPoliciesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.openAuthenticationPolicies = mapped
    }

    /**
     * @param argument The authentication policies for workflow.
     */
    @JvmName("ssqropcpewrjggyk")
    public suspend
    fun openAuthenticationPolicies(argument: suspend OpenAuthenticationAccessPoliciesArgsBuilder.() -> Unit) {
        val toBeMapped = OpenAuthenticationAccessPoliciesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.openAuthenticationPolicies = mapped
    }

    internal fun build(): FlowAccessControlConfigurationPolicyArgs =
        FlowAccessControlConfigurationPolicyArgs(
            allowedCallerIpAddresses = allowedCallerIpAddresses,
            openAuthenticationPolicies = openAuthenticationPolicies,
        )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/logic/kotlin/inputs/FlowAccessControlConfigurationPolicyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.logic.kotlin.inputs

import com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * The access control configuration policy.
 * @property allowedCallerIpAddresses The allowed caller IP address ranges.
 * @property openAuthenticationPolicies The authentication policies for workflow.
 */
public data class FlowAccessControlConfigurationPolicyArgs(
    public val allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null,
    public val openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs> {
    override fun toJava():
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs =
        com.pulumi.azurenative.logic.inputs.FlowAccessControlConfigurationPolicyArgs.builder()
            .allowedCallerIpAddresses(
                allowedCallerIpAddresses?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .openAuthenticationPolicies(
                openAuthenticationPolicies?.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            ).build()
}

/**
 * Builder for [FlowAccessControlConfigurationPolicyArgs].
 */
@PulumiTagMarker
public class FlowAccessControlConfigurationPolicyArgsBuilder internal constructor() {
    private var allowedCallerIpAddresses: Output<List<IpAddressRangeArgs>>? = null

    private var openAuthenticationPolicies: Output<OpenAuthenticationAccessPoliciesArgs>? = null

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("liafnwefgkwwndjl")
    public suspend fun allowedCallerIpAddresses(`value`: Output<List<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = value
    }

    @JvmName("fimjkhqusoraqvxa")
    public suspend fun allowedCallerIpAddresses(vararg values: Output<IpAddressRangeArgs>) {
        this.allowedCallerIpAddresses = Output.all(values.asList())
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("ufpxjmhiqidsgdvj")
    public suspend fun allowedCallerIpAddresses(values: List<Output<IpAddressRangeArgs>>) {
        this.allowedCallerIpAddresses = Output.all(values)
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("womkmtotkcyhgdvq")
    public suspend
    fun openAuthenticationPolicies(`value`: Output<OpenAuthenticationAccessPoliciesArgs>) {
        this.openAuthenticationPolicies = value
    }

    /**
     * @param value The allowed caller IP address ranges.
     */
    @JvmName("nqrvjemlrkgvfnxd")
    public suspend fun allowedCallerIpAddresses(`value`: List<IpAddressRangeArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("andrqkdbxxvegwik")
    public suspend
    fun allowedCallerIpAddresses(argument: List<suspend IpAddressRangeArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("qonxuvtvxdgklyur")
    public suspend fun allowedCallerIpAddresses(
        vararg
        argument: suspend IpAddressRangeArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            IpAddressRangeArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param argument The allowed caller IP address ranges.
     */
    @JvmName("pdxctrtbldrjxtxh")
    public suspend
    fun allowedCallerIpAddresses(argument: suspend IpAddressRangeArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(IpAddressRangeArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param values The allowed caller IP address ranges.
     */
    @JvmName("cpbvxngxqwkpgcaj")
    public suspend fun allowedCallerIpAddresses(vararg values: IpAddressRangeArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.allowedCallerIpAddresses = mapped
    }

    /**
     * @param value The authentication policies for workflow.
     */
    @JvmName("awrmjyiedumurbap")
    public suspend fun openAuthenticationPolicies(`value`: OpenAuthenticationAccessPoliciesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.openAuthenticationPolicies = mapped
    }

    /**
     * @param argument The authentication policies for workflow.
     */
    @JvmName("olpbvemottjxcecf")
    public suspend
    fun openAuthenticationPolicies(argument: suspend OpenAuthenticationAccessPoliciesArgsBuilder.() -> Unit) {
        val toBeMapped = OpenAuthenticationAccessPoliciesArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.openAuthenticationPolicies = mapped
    }

    internal fun build(): FlowAccessControlConfigurationPolicyArgs =
        FlowAccessControlConfigurationPolicyArgs(
            allowedCallerIpAddresses = allowedCallerIpAddresses,
            openAuthenticationPolicies = openAuthenticationPolicies,
        )
}
